<?php

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2012 Tobias Blaser, Otavio Huber, Willi Kernen, <contact@gridds.com>, GRiDDS GmbH
 *  
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Region controller
 *
 * @package grds_language_menu
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License, version 3 or later
 */
class Tx_GrdsLanguageMenu_Controller_RegionController extends Tx_Extbase_MVC_Controller_ActionController {
	
	/**
	 * regionRepository
	 *
	 * @var Tx_GrdsLanguageMenu_Domain_Repository_RegionRepository
	 */
	protected $regionRepository;
	
	/**
	 * translationRepository
	 *
	 * @var Tx_GrdsLanguageMenu_Domain_Repository_TranslationRepository
	 */
	protected $translationRepository;
	
	/**
	 * pageRepository
	 *
	 * @var Tx_GrdsLanguageMenu_Domain_Repository_PageRepository
	 */
	protected $pageRepository;
	
	/**
	 * injectRegionRepository
	 *
	 * @param Tx_GrdsLanguageMenu_Domain_Repository_RegionRepository $regionRepository
	 * @return void
	 */
	public function injectRegionRepository(Tx_GrdsLanguageMenu_Domain_Repository_RegionRepository $regionRepository) {
		$this->regionRepository = $regionRepository;
	}
	
	/**
	 * injectTranslationRepository
	 *
	 * @param Tx_GrdsLanguageMenu_Domain_Repository_TranslationRepository $translationRepository
	 * @return void
	 */	
	public function injectTranslationRepository(Tx_GrdsLanguageMenu_Domain_Repository_TranslationRepository $translationRepository) {
		$this->translationRepository = $translationRepository;
	}
	
	/**
	 * action list
	 * shows a list of regions with the related languages
	 * 
	 * @return void
	 */
	public function listAction() {
		$regions = $this->regionRepository->findAll();
		$translations = $this->translationRepository->findByPid($GLOBALS['TSFE']->id);
		$translatedLangs = array();
		foreach($translations as $translation) {
			$translatedLangs[] = $translation->getLanguage();
		}
		
		// check for old override syntax ('L1 = 2' instead of 'L1.lang = 2')
		$usingOldOverrideSyntax = false;
		foreach($this->settings['languageParamOverride'] as $langOverride) {
			if(!is_array($langOverride)) {
				$usingOldOverrideSyntax = true;
			}
		}
		
		$this->view->assign('usingOldOverrideSyntax', $usingOldOverrideSyntax);
		$this->view->assign('regions', $regions);
		$this->view->assign('translations',$translatedLangs);
	}
}

?>