<?php

/***************************************************************
 *  Copyright notice
 *
 *  (c) 2012 Tobias Blaser, Otavio Huber, Willi Kernen, <contact@gridds.com>, GRiDDS GmbH
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

/**
 * Language mapping ViewHelper
 * Override the give language with the mapped, if exist, if not, return the default language
 *
 * @package grds_language_menu
 * @license http://www.gnu.org/licenses/lgpl.html GNU Lesser General Public License, version 3 or later
 */
class Tx_GrdsLanguageMenu_ViewHelpers_Lang_LanguageMappingViewHelper extends Tx_Fluid_Core_ViewHelper_AbstractViewHelper {

	/**
	 * render function
	 *
	 * @param mixed $setting The path to the language setting to check for existence
	 * @param mixed $default The value do show if the argument doesn't exist
	 * @return The language object
	 */
	public function render($setting, $default) {
		$defaultLang = '0';
		$settingsPrefix = 'settings.';	
		$settings = Tx_GrdsLanguageMenu_Service_TsSettings::getTsSetup('tx_grdslanguagemenu');	
	
		// prepair given setting path and split it to array
		$setting = (substr($setting, 0, strlen($settingsPrefix)) === $settingsPrefix) ? str_replace('settings.', '', $setting) : $setting;
		$settingPath = split('\.', $setting);
		$langSetting = $settings;

		// loop through setting path and return mapped value if exist, otherwise return default value
		foreach ($settingPath as $path) {
			if ($langSetting[$path] || $langSetting[$path]==0) {
				if (is_array($langSetting[$path])) {
					$langSetting = $langSetting[$path];
				} else {
					if($langSetting[$path] == $defaultLang) {
						return $langSetting[$path];
					} else {
						$languageRepository = t3lib_div::makeInstance('Tx_GrdsLanguageMenu_Domain_Repository_LanguageRepository');
						$lang = $languageRepository->findByUid($langSetting[$path]);
						return ($lang) ? $lang : $default;
					}
				}
			} else {
				break;
			}
		}
		return $default;
	}
}
?>